==> gsphonebook-0.4.tar.bz2: gsphonebook-0.4/html/index.php <==
<?php
require("index.common.php");

function get_logininfo() {
	$html = sprintf("%s (%s): %s @ %s",
			$_SESSION['username'],
			$_SESSION['ext'],
			$_SESSION['phone'],
			$_SESSION['gshostname']);
	return $html;
}

update_blf();

echo '<?xml version="1.0" encoding="UTF-8"?>'
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
	<head>
		<meta http-equiv="content-type" content="application/xhtml+xml; charset=UTF-8" />
		<title><?=_("Asterisk GS Phonebook");?></title> 
		<link rel="stylesheet" type="text/css" href="styles.css">
		<?php $xajax->printJavascript($xajaxdir); ?> 
		<script src="functions.js" type="text/javascript"></script>
	</head> 
	<body> 
		<div id='logininfo' class='logininfo'><?=get_logininfo()?></div>
		<h1><?=_("GS/* phonebook")?> v0.4</h1>
		<ul class="menu" id='menu'>
			<!--<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="searchFunc(document.getElementById('searchbox').value);"/></li>-->
			<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="OnKeyRequestBuffer.modified('searchbox');"/></li>
			<li><a href="#" onclick="setSearchType('phonebook');xajax_pb_search('');return false;"><?=_("Phonebook")?></a></li>
			<li><a href="#" onclick="setSearchType('history');xajax_history_search('');return false;"><?=_("Call history")?></a></li>
			<li><a href="#" onclick="setSearchType('off');xajax_up_display('');return false;"><?=_("Preferences")?></a></li>
			<?php if($_SESSION['admin']) { ?>
			<li><a href="#" onclick="setSearchType('off');xajax_admin('');return false;"><?=_("Administration")?></a></li>
			<?php } ?>
			<li><a href="index.php?logout=1"><?=_("Logout")?></a></li>
		</ul>
		<div class="blflist" id="blflist"><?=html_blf()?></div>
		<ul class="submenu" id='submenu'></ul>
		<div class="callinfo" id="callinfo"></div>
		<div class="content" id="content">
		<?php
			require_once("phonebook.php");
			$pb = new phonebook();
			print $pb->get_list("");
		?>
		</div>
	</body> 
</html>

==> gsphonebook-0.7b.tar.bz2: gsphonebook-0.7b/html/index.php <==
<?php
require("index.common.php");

function get_logininfo() {
	$html = sprintf("%s (%s): %s @ %s",
			$_SESSION['username'],
			$_SESSION['ext'],
			$_SESSION['phone'],
			$_SESSION['gshostname']);
	return $html;
}

update_blf();

echo '<?xml version="1.0" encoding="UTF-8"?>'
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
	<head>
		<meta http-equiv="content-type" content="application/xhtml+xml; charset=UTF-8" />
		<title><?=_("GS/* phonebook + WebBLF");?></title> 
		<link rel="stylesheet" type="text/css" href="styles.css">
		<?php $xajax->printJavascript($xajaxdir); ?> 
		<script src="functions.js" type="text/javascript"></script>
	</head> 
	<body> 
		<div id='logininfo' class='logininfo'><?=get_logininfo()?></div>
		<h1><?=_("GS/* phonebook + WebBLF")?> v0.7b</h1>
		<ul class="menu" id='menu'>
			<!--<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="searchFunc(document.getElementById('searchbox').value);"/></li>-->
			<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="OnKeyRequestBuffer.modified('searchbox');"/><a href="javascript:return false;"><img class="clear" src="images/clear.png" alt="<?=_("Clear searchbox")?>" title="<?=_("Clear searchbox")?>" onClick="document.getElementById('searchbox').value='';OnKeyRequestBuffer.modified('searchbox');"></a></li>
			<li><a href="#" onclick="setSearchType('phonebook');xajax_pb_search('');return false;"><?=_("Phonebook")?></a></li>
			<li><a href="#" onclick="setSearchType('history');xajax_history_search('');return false;"><?=_("Call history")?></a></li>
			<li><a href="#" onclick="setSearchType('off');xajax_up_display('');return false;"><?=_("Preferences")?></a></li>
			<?php if($_SESSION['admin']) { ?>
			<li><a href="#" onclick="setSearchType('off');xajax_admin('');return false;"><?=_("Administration")?></a></li>
			<?php } ?>
			<li><a href="index.php?logout=1"><?=_("Logout")?></a></li>
		</ul>
		<div class="blflist" id="blflist"><?=html_blf()?></div>
		<ul class="submenu" id='submenu'></ul>
		<div class="callinfo" id="callinfo"></div>
		<div class="content" id="content">
		<?php
			require_once("phonebook.php");
			$pb = new phonebook();
			print $pb->get_list("");
		?>
		</div>
	</body> 
</html>
